Learn R Programming

qatarcars (version 1.1.0)

qatarcars-package: qatarcars: Data on Cars in Qatar

Description

Fuel economy, size, performance, and price data for cars in Qatar in 2025. Mirrors many of the columns in mtcars, but uses (1) non-US-centric makes and models, (2) 2025 prices, and (3) metric measurements, making it more appropriate for use as an example dataset outside the United States. For more details see Musgrave (2025) tools:::Rd_expr_doi("10.1080/15512169.2025.2572320").

Arguments

Author

Maintainer: Paul Musgrave rpm47@georgetown.edu (ORCID) [copyright holder]

Authors:

See Also