Learn R Programming

qatarcars (version 1.0.0)

qatarcars-package: qatarcars: Data on Cars in Qatar

Description

Fuel economy, size, performance, and price data for cars in Qatar in 2025. Mirrors many of the columns in mtcars, but uses (1) non-US-centric makes and models, (2) 2025 prices, and (3) metric measurements, making it more appropriate for use as an example dataset outside the United States.

Arguments

Author

Maintainer: Paul Musgrave rpm47@georgetown.edu (ORCID) [copyright holder]

Authors:

See Also