set_label: Add a label attribute to an input value only if it already has a label attribute
Description
This is useful with conversion functions since columns in qatarcars have
labels already, and if a conversion function is used on them, that label
carries over.
Usage
set_label(value, original, label)